@@ -73,8 +73,8 @@ exports.serve = function (nylon_path) {
 
         watcher.addWatcher(nylon_path + '/java');
         watcher.addWatcher(nylon_path + '/lib');
-        
-       
+
+
 
     } else {
         // var fs_package = require('fs');
@@ -98,21 +98,29 @@ exports.serve = function (nylon_path) {
 
         var app = application(nylon_path);
 
-        var options = {
-            key: fs.readFileSync(work_dir + '/ssl/server.key'),
-            cert: fs.readFileSync(work_dir + '/ssl/server.crt'),
-           /* spdy: {
-                protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
-                plain: false,
-                'x-forwarded-for': true,
-                connection: {
-                    windowSize: 1024 * 1024,
-                    autoSpdy31: false
-                }
-            }*/
-        };
 
-        var server = http2.createServer(options, app);
+
+        var server = null;
+        if (config.h2.enable) {
+            var options = {
+                key: fs.readFileSync(work_dir + config.h2.ssl.key),
+                cert: fs.readFileSync(work_dir + config.h2.ssl.cert),
+                spdy: {
+                    protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
+                    plain: false,
+                    'x-forwarded-for': true,
+                    connection: {
+                        windowSize: 1024 * 1024,
+                        autoSpdy31: false
+                    }
+                }
+            };
+            server = http2.createServer(options, app);
+        }else{
+            server =http.createServer(app); 
+        }
+
+     //   var server = http2.createServer(options, app);
 
         server.listen(config.server.port, function (error) {
             if (error) {
