@@ -12,11 +12,13 @@
 var morgan=require('morgan');
 var compression=require('compression');
 
-module.exports=function(app){
+module.exports=function(callback,app){
     if (process.env.NODE_ENV === 'development') {
         app.use(morgan('dev'));
+        
     }else{
-         app.use(compression());
+        app.use(compression());
     }
+    callback();
 
 }
\ No newline at end of file
