@@ -11,8 +11,8 @@
 
 var bodyParser=require('body-parser');
 
-module.exports=function(app){
+module.exports=function(callback,app){
     app.use(bodyParser.urlencoded({ extended: true }));
     app.use(bodyParser.json());
-
+    callback();
 }
\ No newline at end of file
