@@ -18,6 +18,7 @@ var logger = require('winston');
 var async = require('async');
 var fscan = require('./../common/fscan');
 const config = require(process.cwd() + '/config/config');
+var passport = require('passport');
 
 
 var loadRouter = function (app, routes, callback) {
@@ -30,7 +31,7 @@ var loadRouter = function (app, routes, callback) {
 
             var router = express.Router();
             require(route)(router);
-            app.use("/api" + rname, router);
+            app.use("/api" + rname, passport.authenticate('jwt', { session: false }), router);
             // logger.info(prefix+"/"+rname);
             logger.info("nylon start route ::  /api" + rname + " >> " + route_dir + rname + ".routes.js");
             next();
